@@ -201,7 +201,7 @@ void ActionManagerImpl::initPart()
     configure->setIcon(QIcon::fromTheme(QStringLiteral("configure")));
     connect(configure, &QAction::triggered, d->part, &Part::showOptions);
 
-    KStandardAction::configureNotifications(d->part, &Part::showNotificationOptions, d->actionCollection); // options_configure_notifications
+    KStandardActions::configureNotifications(d->part, &Part::showNotificationOptions, d->actionCollection); // options_configure_notifications
 }
 
 void ActionManagerImpl::initMainWidget(MainWidget *mainWidget)
@@ -436,7 +436,11 @@ void ActionManagerImpl::initMainWidget(MainWidget *mainWidget)
     coll->addAction(QStringLiteral("focus_to_quickseach"), d->mQuickSearchAction);
     connect(d->mQuickSearchAction, &QAction::triggered, mainWidget, &MainWidget::slotFocusQuickSearch);
 
-    auto manager = new KColorSchemeManager(this);
+    auto showWhatsNewAction = new QAction(QIcon::fromTheme(QStringLiteral("akregator")), i18n("What's new"), this);
+    coll->addAction(QStringLiteral("whatsnew"), showWhatsNewAction);
+    connect(showWhatsNewAction, &QAction::triggered, mainWidget, &MainWidget::slotWhatsNew);
+
+    auto manager = KColorSchemeManager::instance();
     coll->addAction(QStringLiteral("colorscheme_menu"), KColorSchemeMenu::createMenu(manager, this));
 
     setArticleActionsEnabled(false);
@@ -578,13 +582,13 @@ void ActionManagerImpl::initTabWidget(TabWidget *tabWidget)
     connect(action, &QAction::triggered, d->tabWidget, &TabWidget::slotDetachTab);
     coll->setDefaultShortcut(action, QKeySequence(Qt::CTRL | Qt::SHIFT | Qt::Key_B));
 
-    action = KStandardAction::copy(d->tabWidget, &TabWidget::slotCopy, coll);
+    action = KStandardActions::copy(d->tabWidget, &TabWidget::slotCopy, coll);
     coll->addAction(QStringLiteral("viewer_copy"), action);
 
-    action = KStandardAction::print(d->tabWidget, &TabWidget::slotPrint, coll);
+    action = KStandardActions::print(d->tabWidget, &TabWidget::slotPrint, coll);
     coll->addAction(QStringLiteral("viewer_print"), action);
 
-    action = KStandardAction::printPreview(d->tabWidget, &TabWidget::slotPrintPreview, coll);
+    action = KStandardActions::printPreview(d->tabWidget, &TabWidget::slotPrintPreview, coll);
     coll->addAction(QStringLiteral("viewer_printpreview"), action);
 
     action = coll->addAction(QStringLiteral("tab_mute"));
